# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineRegisterRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bios': 'V1MachineBIOS',
        'hardware': 'V1MachineHardwareExtended',
        'ipmi': 'V1MachineIPMI',
        'partitionid': 'str',
        'rackid': 'str',
        'tags': 'list[str]',
        'uuid': 'str'
    }

    attribute_map = {
        'bios': 'bios',
        'hardware': 'hardware',
        'ipmi': 'ipmi',
        'partitionid': 'partitionid',
        'rackid': 'rackid',
        'tags': 'tags',
        'uuid': 'uuid'
    }

    def __init__(self, bios=None, hardware=None, ipmi=None, partitionid=None, rackid=None, tags=None, uuid=None):  # noqa: E501
        """V1MachineRegisterRequest - a model defined in Swagger"""  # noqa: E501

        self._bios = None
        self._hardware = None
        self._ipmi = None
        self._partitionid = None
        self._rackid = None
        self._tags = None
        self._uuid = None
        self.discriminator = None

        self.bios = bios
        self.hardware = hardware
        self.ipmi = ipmi
        self.partitionid = partitionid
        self.rackid = rackid
        self.tags = tags
        self.uuid = uuid

    @property
    def bios(self):
        """Gets the bios of this V1MachineRegisterRequest.  # noqa: E501

        bios information of this machine  # noqa: E501

        :return: The bios of this V1MachineRegisterRequest.  # noqa: E501
        :rtype: V1MachineBIOS
        """
        return self._bios

    @bios.setter
    def bios(self, bios):
        """Sets the bios of this V1MachineRegisterRequest.

        bios information of this machine  # noqa: E501

        :param bios: The bios of this V1MachineRegisterRequest.  # noqa: E501
        :type: V1MachineBIOS
        """
        if bios is None:
            raise ValueError("Invalid value for `bios`, must not be `None`")  # noqa: E501

        self._bios = bios

    @property
    def hardware(self):
        """Gets the hardware of this V1MachineRegisterRequest.  # noqa: E501

        the hardware of this machine  # noqa: E501

        :return: The hardware of this V1MachineRegisterRequest.  # noqa: E501
        :rtype: V1MachineHardwareExtended
        """
        return self._hardware

    @hardware.setter
    def hardware(self, hardware):
        """Sets the hardware of this V1MachineRegisterRequest.

        the hardware of this machine  # noqa: E501

        :param hardware: The hardware of this V1MachineRegisterRequest.  # noqa: E501
        :type: V1MachineHardwareExtended
        """
        if hardware is None:
            raise ValueError("Invalid value for `hardware`, must not be `None`")  # noqa: E501

        self._hardware = hardware

    @property
    def ipmi(self):
        """Gets the ipmi of this V1MachineRegisterRequest.  # noqa: E501

        the ipmi access infos  # noqa: E501

        :return: The ipmi of this V1MachineRegisterRequest.  # noqa: E501
        :rtype: V1MachineIPMI
        """
        return self._ipmi

    @ipmi.setter
    def ipmi(self, ipmi):
        """Sets the ipmi of this V1MachineRegisterRequest.

        the ipmi access infos  # noqa: E501

        :param ipmi: The ipmi of this V1MachineRegisterRequest.  # noqa: E501
        :type: V1MachineIPMI
        """
        if ipmi is None:
            raise ValueError("Invalid value for `ipmi`, must not be `None`")  # noqa: E501

        self._ipmi = ipmi

    @property
    def partitionid(self):
        """Gets the partitionid of this V1MachineRegisterRequest.  # noqa: E501

        the partition id to register this machine with  # noqa: E501

        :return: The partitionid of this V1MachineRegisterRequest.  # noqa: E501
        :rtype: str
        """
        return self._partitionid

    @partitionid.setter
    def partitionid(self, partitionid):
        """Sets the partitionid of this V1MachineRegisterRequest.

        the partition id to register this machine with  # noqa: E501

        :param partitionid: The partitionid of this V1MachineRegisterRequest.  # noqa: E501
        :type: str
        """
        if partitionid is None:
            raise ValueError("Invalid value for `partitionid`, must not be `None`")  # noqa: E501

        self._partitionid = partitionid

    @property
    def rackid(self):
        """Gets the rackid of this V1MachineRegisterRequest.  # noqa: E501

        the rack id where this machine is connected to  # noqa: E501

        :return: The rackid of this V1MachineRegisterRequest.  # noqa: E501
        :rtype: str
        """
        return self._rackid

    @rackid.setter
    def rackid(self, rackid):
        """Sets the rackid of this V1MachineRegisterRequest.

        the rack id where this machine is connected to  # noqa: E501

        :param rackid: The rackid of this V1MachineRegisterRequest.  # noqa: E501
        :type: str
        """
        if rackid is None:
            raise ValueError("Invalid value for `rackid`, must not be `None`")  # noqa: E501

        self._rackid = rackid

    @property
    def tags(self):
        """Gets the tags of this V1MachineRegisterRequest.  # noqa: E501

        tags for this machine  # noqa: E501

        :return: The tags of this V1MachineRegisterRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this V1MachineRegisterRequest.

        tags for this machine  # noqa: E501

        :param tags: The tags of this V1MachineRegisterRequest.  # noqa: E501
        :type: list[str]
        """
        if tags is None:
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    @property
    def uuid(self):
        """Gets the uuid of this V1MachineRegisterRequest.  # noqa: E501

        the product uuid of the machine to register  # noqa: E501

        :return: The uuid of this V1MachineRegisterRequest.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this V1MachineRegisterRequest.

        the product uuid of the machine to register  # noqa: E501

        :param uuid: The uuid of this V1MachineRegisterRequest.  # noqa: E501
        :type: str
        """
        if uuid is None:
            raise ValueError("Invalid value for `uuid`, must not be `None`")  # noqa: E501

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineRegisterRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineRegisterRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.network_api import NetworkApi  # noqa: E501
from metal_python.rest import ApiException


class TestNetworkApi(unittest.TestCase):
    """NetworkApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.network_api.NetworkApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_allocate_network(self):
        """Test case for allocate_network

        allocates a child network from a partition's private super network  # noqa: E501
        """
        pass

    def test_create_network(self):
        """Test case for create_network

        create a network. if the given ID already exists a conflict is returned  # noqa: E501
        """
        pass

    def test_delete_network(self):
        """Test case for delete_network

        deletes a network and returns the deleted entity  # noqa: E501
        """
        pass

    def test_find_network(self):
        """Test case for find_network

        get network by id  # noqa: E501
        """
        pass

    def test_find_networks(self):
        """Test case for find_networks

        get all networks that match given properties  # noqa: E501
        """
        pass

    def test_free_network(self):
        """Test case for free_network

        free a network  # noqa: E501
        """
        pass

    def test_list_networks(self):
        """Test case for list_networks

        get all networks  # noqa: E501
        """
        pass

    def test_update_network(self):
        """Test case for update_network

        updates a network. if the network was changed since this one was read, a conflict is returned  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineAllocation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'boot_info': 'V1BootInfo',
        'console_password': 'str',
        'created': 'datetime',
        'description': 'str',
        'hostname': 'str',
        'image': 'V1ImageResponse',
        'name': 'str',
        'networks': 'list[V1MachineNetwork]',
        'project': 'str',
        'reinstall': 'bool',
        'ssh_pub_keys': 'list[str]',
        'succeeded': 'bool',
        'user_data': 'str'
    }

    attribute_map = {
        'boot_info': 'boot_info',
        'console_password': 'console_password',
        'created': 'created',
        'description': 'description',
        'hostname': 'hostname',
        'image': 'image',
        'name': 'name',
        'networks': 'networks',
        'project': 'project',
        'reinstall': 'reinstall',
        'ssh_pub_keys': 'ssh_pub_keys',
        'succeeded': 'succeeded',
        'user_data': 'user_data'
    }

    def __init__(self, boot_info=None, console_password=None, created=None, description=None, hostname=None, image=None, name=None, networks=None, project=None, reinstall=None, ssh_pub_keys=None, succeeded=None, user_data=None):  # noqa: E501
        """V1MachineAllocation - a model defined in Swagger"""  # noqa: E501

        self._boot_info = None
        self._console_password = None
        self._created = None
        self._description = None
        self._hostname = None
        self._image = None
        self._name = None
        self._networks = None
        self._project = None
        self._reinstall = None
        self._ssh_pub_keys = None
        self._succeeded = None
        self._user_data = None
        self.discriminator = None

        if boot_info is not None:
            self.boot_info = boot_info
        if console_password is not None:
            self.console_password = console_password
        self.created = created
        if description is not None:
            self.description = description
        self.hostname = hostname
        if image is not None:
            self.image = image
        self.name = name
        self.networks = networks
        self.project = project
        self.reinstall = reinstall
        self.ssh_pub_keys = ssh_pub_keys
        self.succeeded = succeeded
        if user_data is not None:
            self.user_data = user_data

    @property
    def boot_info(self):
        """Gets the boot_info of this V1MachineAllocation.  # noqa: E501

        information required for booting the machine from HD  # noqa: E501

        :return: The boot_info of this V1MachineAllocation.  # noqa: E501
        :rtype: V1BootInfo
        """
        return self._boot_info

    @boot_info.setter
    def boot_info(self, boot_info):
        """Sets the boot_info of this V1MachineAllocation.

        information required for booting the machine from HD  # noqa: E501

        :param boot_info: The boot_info of this V1MachineAllocation.  # noqa: E501
        :type: V1BootInfo
        """

        self._boot_info = boot_info

    @property
    def console_password(self):
        """Gets the console_password of this V1MachineAllocation.  # noqa: E501

        the console password which was generated while provisioning  # noqa: E501

        :return: The console_password of this V1MachineAllocation.  # noqa: E501
        :rtype: str
        """
        return self._console_password

    @console_password.setter
    def console_password(self, console_password):
        """Sets the console_password of this V1MachineAllocation.

        the console password which was generated while provisioning  # noqa: E501

        :param console_password: The console_password of this V1MachineAllocation.  # noqa: E501
        :type: str
        """

        self._console_password = console_password

    @property
    def created(self):
        """Gets the created of this V1MachineAllocation.  # noqa: E501

        the time when the machine was created  # noqa: E501

        :return: The created of this V1MachineAllocation.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this V1MachineAllocation.

        the time when the machine was created  # noqa: E501

        :param created: The created of this V1MachineAllocation.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def description(self):
        """Gets the description of this V1MachineAllocation.  # noqa: E501

        a description for this machine  # noqa: E501

        :return: The description of this V1MachineAllocation.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1MachineAllocation.

        a description for this machine  # noqa: E501

        :param description: The description of this V1MachineAllocation.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def hostname(self):
        """Gets the hostname of this V1MachineAllocation.  # noqa: E501

        the hostname which will be used when creating the machine  # noqa: E501

        :return: The hostname of this V1MachineAllocation.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this V1MachineAllocation.

        the hostname which will be used when creating the machine  # noqa: E501

        :param hostname: The hostname of this V1MachineAllocation.  # noqa: E501
        :type: str
        """
        if hostname is None:
            raise ValueError("Invalid value for `hostname`, must not be `None`")  # noqa: E501

        self._hostname = hostname

    @property
    def image(self):
        """Gets the image of this V1MachineAllocation.  # noqa: E501

        the image assigned to this machine  # noqa: E501

        :return: The image of this V1MachineAllocation.  # noqa: E501
        :rtype: V1ImageResponse
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this V1MachineAllocation.

        the image assigned to this machine  # noqa: E501

        :param image: The image of this V1MachineAllocation.  # noqa: E501
        :type: V1ImageResponse
        """

        self._image = image

    @property
    def name(self):
        """Gets the name of this V1MachineAllocation.  # noqa: E501

        the name of the machine  # noqa: E501

        :return: The name of this V1MachineAllocation.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1MachineAllocation.

        the name of the machine  # noqa: E501

        :param name: The name of this V1MachineAllocation.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def networks(self):
        """Gets the networks of this V1MachineAllocation.  # noqa: E501

        the networks of this machine  # noqa: E501

        :return: The networks of this V1MachineAllocation.  # noqa: E501
        :rtype: list[V1MachineNetwork]
        """
        return self._networks

    @networks.setter
    def networks(self, networks):
        """Sets the networks of this V1MachineAllocation.

        the networks of this machine  # noqa: E501

        :param networks: The networks of this V1MachineAllocation.  # noqa: E501
        :type: list[V1MachineNetwork]
        """
        if networks is None:
            raise ValueError("Invalid value for `networks`, must not be `None`")  # noqa: E501

        self._networks = networks

    @property
    def project(self):
        """Gets the project of this V1MachineAllocation.  # noqa: E501

        the project id that this machine is assigned to  # noqa: E501

        :return: The project of this V1MachineAllocation.  # noqa: E501
        :rtype: str
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this V1MachineAllocation.

        the project id that this machine is assigned to  # noqa: E501

        :param project: The project of this V1MachineAllocation.  # noqa: E501
        :type: str
        """
        if project is None:
            raise ValueError("Invalid value for `project`, must not be `None`")  # noqa: E501

        self._project = project

    @property
    def reinstall(self):
        """Gets the reinstall of this V1MachineAllocation.  # noqa: E501

        indicates whether to reinstall the machine  # noqa: E501

        :return: The reinstall of this V1MachineAllocation.  # noqa: E501
        :rtype: bool
        """
        return self._reinstall

    @reinstall.setter
    def reinstall(self, reinstall):
        """Sets the reinstall of this V1MachineAllocation.

        indicates whether to reinstall the machine  # noqa: E501

        :param reinstall: The reinstall of this V1MachineAllocation.  # noqa: E501
        :type: bool
        """
        if reinstall is None:
            raise ValueError("Invalid value for `reinstall`, must not be `None`")  # noqa: E501

        self._reinstall = reinstall

    @property
    def ssh_pub_keys(self):
        """Gets the ssh_pub_keys of this V1MachineAllocation.  # noqa: E501

        the public ssh keys to access the machine with  # noqa: E501

        :return: The ssh_pub_keys of this V1MachineAllocation.  # noqa: E501
        :rtype: list[str]
        """
        return self._ssh_pub_keys

    @ssh_pub_keys.setter
    def ssh_pub_keys(self, ssh_pub_keys):
        """Sets the ssh_pub_keys of this V1MachineAllocation.

        the public ssh keys to access the machine with  # noqa: E501

        :param ssh_pub_keys: The ssh_pub_keys of this V1MachineAllocation.  # noqa: E501
        :type: list[str]
        """
        if ssh_pub_keys is None:
            raise ValueError("Invalid value for `ssh_pub_keys`, must not be `None`")  # noqa: E501

        self._ssh_pub_keys = ssh_pub_keys

    @property
    def succeeded(self):
        """Gets the succeeded of this V1MachineAllocation.  # noqa: E501

        if the allocation of the machine was successful, this is set to true  # noqa: E501

        :return: The succeeded of this V1MachineAllocation.  # noqa: E501
        :rtype: bool
        """
        return self._succeeded

    @succeeded.setter
    def succeeded(self, succeeded):
        """Sets the succeeded of this V1MachineAllocation.

        if the allocation of the machine was successful, this is set to true  # noqa: E501

        :param succeeded: The succeeded of this V1MachineAllocation.  # noqa: E501
        :type: bool
        """
        if succeeded is None:
            raise ValueError("Invalid value for `succeeded`, must not be `None`")  # noqa: E501

        self._succeeded = succeeded

    @property
    def user_data(self):
        """Gets the user_data of this V1MachineAllocation.  # noqa: E501

        userdata to execute post installation tasks  # noqa: E501

        :return: The user_data of this V1MachineAllocation.  # noqa: E501
        :rtype: str
        """
        return self._user_data

    @user_data.setter
    def user_data(self, user_data):
        """Sets the user_data of this V1MachineAllocation.

        userdata to execute post installation tasks  # noqa: E501

        :param user_data: The user_data of this V1MachineAllocation.  # noqa: E501
        :type: str
        """

        self._user_data = user_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineAllocation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineAllocation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.switch_api import SwitchApi  # noqa: E501
from metal_python.rest import ApiException


class TestSwitchApi(unittest.TestCase):
    """SwitchApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.switch_api.SwitchApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_switch(self):
        """Test case for delete_switch

        deletes an switch and returns the deleted entity  # noqa: E501
        """
        pass

    def test_find_switch(self):
        """Test case for find_switch

        get switch by id  # noqa: E501
        """
        pass

    def test_list_switches(self):
        """Test case for list_switches

        get all switches  # noqa: E501
        """
        pass

    def test_notify_switch(self):
        """Test case for notify_switch

        notify the metal-api about a configuration change of a switch  # noqa: E501
        """
        pass

    def test_register_switch(self):
        """Test case for register_switch

        register a switch  # noqa: E501
        """
        pass

    def test_update_switch(self):
        """Test case for update_switch

        updates a switch. if the switch was changed since this one was read, a conflict is returned  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1Quota(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'quota': 'int',
        'used': 'int'
    }

    attribute_map = {
        'quota': 'quota',
        'used': 'used'
    }

    def __init__(self, quota=None, used=None):  # noqa: E501
        """V1Quota - a model defined in Swagger"""  # noqa: E501

        self._quota = None
        self._used = None
        self.discriminator = None

        if quota is not None:
            self.quota = quota
        if used is not None:
            self.used = used

    @property
    def quota(self):
        """Gets the quota of this V1Quota.  # noqa: E501


        :return: The quota of this V1Quota.  # noqa: E501
        :rtype: int
        """
        return self._quota

    @quota.setter
    def quota(self, quota):
        """Sets the quota of this V1Quota.


        :param quota: The quota of this V1Quota.  # noqa: E501
        :type: int
        """

        self._quota = quota

    @property
    def used(self):
        """Gets the used of this V1Quota.  # noqa: E501


        :return: The used of this V1Quota.  # noqa: E501
        :rtype: int
        """
        return self._used

    @used.setter
    def used(self, used):
        """Sets the used of this V1Quota.


        :param used: The used of this V1Quota.  # noqa: E501
        :type: int
        """

        self._used = used

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Quota, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Quota):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.machine_api import MachineApi  # noqa: E501
from metal_python.rest import ApiException


class TestMachineApi(unittest.TestCase):
    """MachineApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.machine_api.MachineApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_reinstall_machine(self):
        """Test case for abort_reinstall_machine

        abort reinstall this machine  # noqa: E501
        """
        pass

    def test_add_provisioning_event(self):
        """Test case for add_provisioning_event

        adds a machine provisioning event  # noqa: E501
        """
        pass

    def test_allocate_machine(self):
        """Test case for allocate_machine

        allocate a machine  # noqa: E501
        """
        pass

    def test_chassis_identify_led_off(self):
        """Test case for chassis_identify_led_off

        sends a power-off to the chassis identify LED  # noqa: E501
        """
        pass

    def test_chassis_identify_led_on(self):
        """Test case for chassis_identify_led_on

        sends a power-on to the chassis identify LED  # noqa: E501
        """
        pass

    def test_finalize_allocation(self):
        """Test case for finalize_allocation

        finalize the allocation of the machine by reconfiguring the switch, sent on successful image installation  # noqa: E501
        """
        pass

    def test_find_ipmi_machine(self):
        """Test case for find_ipmi_machine

        returns a machine including the ipmi connection data  # noqa: E501
        """
        pass

    def test_find_ipmi_machines(self):
        """Test case for find_ipmi_machines

        returns machines including the ipmi connection data  # noqa: E501
        """
        pass

    def test_find_machine(self):
        """Test case for find_machine

        get machine by id  # noqa: E501
        """
        pass

    def test_find_machines(self):
        """Test case for find_machines

        find machines by multiple criteria  # noqa: E501
        """
        pass

    def test_free_machine(self):
        """Test case for free_machine

        free a machine  # noqa: E501
        """
        pass

    def test_get_provisioning_event_container(self):
        """Test case for get_provisioning_event_container

        get the current machine provisioning event container  # noqa: E501
        """
        pass

    def test_ipmi_report(self):
        """Test case for ipmi_report

        reports IPMI ip addresses leased by a management server for machines  # noqa: E501
        """
        pass

    def test_list_machines(self):
        """Test case for list_machines

        get all known machines  # noqa: E501
        """
        pass

    def test_machine_bios(self):
        """Test case for machine_bios

        boots machine into BIOS on next reboot  # noqa: E501
        """
        pass

    def test_machine_off(self):
        """Test case for machine_off

        sends a power-off to the machine  # noqa: E501
        """
        pass

    def test_machine_on(self):
        """Test case for machine_on

        sends a power-on to the machine  # noqa: E501
        """
        pass

    def test_machine_reset(self):
        """Test case for machine_reset

        sends a reset to the machine  # noqa: E501
        """
        pass

    def test_register_machine(self):
        """Test case for register_machine

        register a machine  # noqa: E501
        """
        pass

    def test_reinstall_machine(self):
        """Test case for reinstall_machine

        reinstall this machine  # noqa: E501
        """
        pass

    def test_set_chassis_identify_led_state(self):
        """Test case for set_chassis_identify_led_state

        set the state of a chassis identify LED  # noqa: E501
        """
        pass

    def test_set_machine_state(self):
        """Test case for set_machine_state

        set the state of a machine  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineIPMI(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'bmcversion': 'str',
        'fru': 'V1MachineFru',
        'interface': 'str',
        'mac': 'str',
        'password': 'str',
        'user': 'str'
    }

    attribute_map = {
        'address': 'address',
        'bmcversion': 'bmcversion',
        'fru': 'fru',
        'interface': 'interface',
        'mac': 'mac',
        'password': 'password',
        'user': 'user'
    }

    def __init__(self, address=None, bmcversion=None, fru=None, interface=None, mac=None, password=None, user=None):  # noqa: E501
        """V1MachineIPMI - a model defined in Swagger"""  # noqa: E501

        self._address = None
        self._bmcversion = None
        self._fru = None
        self._interface = None
        self._mac = None
        self._password = None
        self._user = None
        self.discriminator = None

        self.address = address
        self.bmcversion = bmcversion
        self.fru = fru
        self.interface = interface
        self.mac = mac
        self.password = password
        self.user = user

    @property
    def address(self):
        """Gets the address of this V1MachineIPMI.  # noqa: E501


        :return: The address of this V1MachineIPMI.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this V1MachineIPMI.


        :param address: The address of this V1MachineIPMI.  # noqa: E501
        :type: str
        """
        if address is None:
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def bmcversion(self):
        """Gets the bmcversion of this V1MachineIPMI.  # noqa: E501


        :return: The bmcversion of this V1MachineIPMI.  # noqa: E501
        :rtype: str
        """
        return self._bmcversion

    @bmcversion.setter
    def bmcversion(self, bmcversion):
        """Sets the bmcversion of this V1MachineIPMI.


        :param bmcversion: The bmcversion of this V1MachineIPMI.  # noqa: E501
        :type: str
        """
        if bmcversion is None:
            raise ValueError("Invalid value for `bmcversion`, must not be `None`")  # noqa: E501

        self._bmcversion = bmcversion

    @property
    def fru(self):
        """Gets the fru of this V1MachineIPMI.  # noqa: E501


        :return: The fru of this V1MachineIPMI.  # noqa: E501
        :rtype: V1MachineFru
        """
        return self._fru

    @fru.setter
    def fru(self, fru):
        """Sets the fru of this V1MachineIPMI.


        :param fru: The fru of this V1MachineIPMI.  # noqa: E501
        :type: V1MachineFru
        """
        if fru is None:
            raise ValueError("Invalid value for `fru`, must not be `None`")  # noqa: E501

        self._fru = fru

    @property
    def interface(self):
        """Gets the interface of this V1MachineIPMI.  # noqa: E501


        :return: The interface of this V1MachineIPMI.  # noqa: E501
        :rtype: str
        """
        return self._interface

    @interface.setter
    def interface(self, interface):
        """Sets the interface of this V1MachineIPMI.


        :param interface: The interface of this V1MachineIPMI.  # noqa: E501
        :type: str
        """
        if interface is None:
            raise ValueError("Invalid value for `interface`, must not be `None`")  # noqa: E501

        self._interface = interface

    @property
    def mac(self):
        """Gets the mac of this V1MachineIPMI.  # noqa: E501


        :return: The mac of this V1MachineIPMI.  # noqa: E501
        :rtype: str
        """
        return self._mac

    @mac.setter
    def mac(self, mac):
        """Sets the mac of this V1MachineIPMI.


        :param mac: The mac of this V1MachineIPMI.  # noqa: E501
        :type: str
        """
        if mac is None:
            raise ValueError("Invalid value for `mac`, must not be `None`")  # noqa: E501

        self._mac = mac

    @property
    def password(self):
        """Gets the password of this V1MachineIPMI.  # noqa: E501


        :return: The password of this V1MachineIPMI.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this V1MachineIPMI.


        :param password: The password of this V1MachineIPMI.  # noqa: E501
        :type: str
        """
        if password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def user(self):
        """Gets the user of this V1MachineIPMI.  # noqa: E501


        :return: The user of this V1MachineIPMI.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this V1MachineIPMI.


        :param user: The user of this V1MachineIPMI.  # noqa: E501
        :type: str
        """
        if user is None:
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineIPMI, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineIPMI):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1IPFindRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ipaddress': 'str',
        'machineid': 'str',
        'networkid': 'str',
        'networkprefix': 'str',
        'projectid': 'str',
        'tags': 'list[str]',
        'type': 'str'
    }

    attribute_map = {
        'ipaddress': 'ipaddress',
        'machineid': 'machineid',
        'networkid': 'networkid',
        'networkprefix': 'networkprefix',
        'projectid': 'projectid',
        'tags': 'tags',
        'type': 'type'
    }

    def __init__(self, ipaddress=None, machineid=None, networkid=None, networkprefix=None, projectid=None, tags=None, type=None):  # noqa: E501
        """V1IPFindRequest - a model defined in Swagger"""  # noqa: E501

        self._ipaddress = None
        self._machineid = None
        self._networkid = None
        self._networkprefix = None
        self._projectid = None
        self._tags = None
        self._type = None
        self.discriminator = None

        if ipaddress is not None:
            self.ipaddress = ipaddress
        if machineid is not None:
            self.machineid = machineid
        if networkid is not None:
            self.networkid = networkid
        if networkprefix is not None:
            self.networkprefix = networkprefix
        if projectid is not None:
            self.projectid = projectid
        if tags is not None:
            self.tags = tags
        if type is not None:
            self.type = type

    @property
    def ipaddress(self):
        """Gets the ipaddress of this V1IPFindRequest.  # noqa: E501

        the address (ipv4 or ipv6) of this ip  # noqa: E501

        :return: The ipaddress of this V1IPFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._ipaddress

    @ipaddress.setter
    def ipaddress(self, ipaddress):
        """Sets the ipaddress of this V1IPFindRequest.

        the address (ipv4 or ipv6) of this ip  # noqa: E501

        :param ipaddress: The ipaddress of this V1IPFindRequest.  # noqa: E501
        :type: str
        """

        self._ipaddress = ipaddress

    @property
    def machineid(self):
        """Gets the machineid of this V1IPFindRequest.  # noqa: E501

        the machine an ip address is associated to  # noqa: E501

        :return: The machineid of this V1IPFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._machineid

    @machineid.setter
    def machineid(self, machineid):
        """Sets the machineid of this V1IPFindRequest.

        the machine an ip address is associated to  # noqa: E501

        :param machineid: The machineid of this V1IPFindRequest.  # noqa: E501
        :type: str
        """

        self._machineid = machineid

    @property
    def networkid(self):
        """Gets the networkid of this V1IPFindRequest.  # noqa: E501

        the network this ip allocate request address belongs to  # noqa: E501

        :return: The networkid of this V1IPFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._networkid

    @networkid.setter
    def networkid(self, networkid):
        """Sets the networkid of this V1IPFindRequest.

        the network this ip allocate request address belongs to  # noqa: E501

        :param networkid: The networkid of this V1IPFindRequest.  # noqa: E501
        :type: str
        """

        self._networkid = networkid

    @property
    def networkprefix(self):
        """Gets the networkprefix of this V1IPFindRequest.  # noqa: E501

        the prefix of the network this ip address belongs to  # noqa: E501

        :return: The networkprefix of this V1IPFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._networkprefix

    @networkprefix.setter
    def networkprefix(self, networkprefix):
        """Sets the networkprefix of this V1IPFindRequest.

        the prefix of the network this ip address belongs to  # noqa: E501

        :param networkprefix: The networkprefix of this V1IPFindRequest.  # noqa: E501
        :type: str
        """

        self._networkprefix = networkprefix

    @property
    def projectid(self):
        """Gets the projectid of this V1IPFindRequest.  # noqa: E501

        the project this ip address belongs to, empty if not strong coupled  # noqa: E501

        :return: The projectid of this V1IPFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._projectid

    @projectid.setter
    def projectid(self, projectid):
        """Sets the projectid of this V1IPFindRequest.

        the project this ip address belongs to, empty if not strong coupled  # noqa: E501

        :param projectid: The projectid of this V1IPFindRequest.  # noqa: E501
        :type: str
        """

        self._projectid = projectid

    @property
    def tags(self):
        """Gets the tags of this V1IPFindRequest.  # noqa: E501

        the tags that are assigned to this ip address  # noqa: E501

        :return: The tags of this V1IPFindRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this V1IPFindRequest.

        the tags that are assigned to this ip address  # noqa: E501

        :param tags: The tags of this V1IPFindRequest.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def type(self):
        """Gets the type of this V1IPFindRequest.  # noqa: E501

        the type of the ip address, ephemeral or static  # noqa: E501

        :return: The type of this V1IPFindRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this V1IPFindRequest.

        the type of the ip address, ephemeral or static  # noqa: E501

        :param type: The type of this V1IPFindRequest.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1IPFindRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1IPFindRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1ProjectCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'meta': 'V1Meta',
        'name': 'str',
        'quotas': 'V1QuotaSet',
        'tenant_id': 'str'
    }

    attribute_map = {
        'description': 'description',
        'meta': 'meta',
        'name': 'name',
        'quotas': 'quotas',
        'tenant_id': 'tenant_id'
    }

    def __init__(self, description=None, meta=None, name=None, quotas=None, tenant_id=None):  # noqa: E501
        """V1ProjectCreateRequest - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._meta = None
        self._name = None
        self._quotas = None
        self._tenant_id = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if meta is not None:
            self.meta = meta
        if name is not None:
            self.name = name
        if quotas is not None:
            self.quotas = quotas
        if tenant_id is not None:
            self.tenant_id = tenant_id

    @property
    def description(self):
        """Gets the description of this V1ProjectCreateRequest.  # noqa: E501


        :return: The description of this V1ProjectCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1ProjectCreateRequest.


        :param description: The description of this V1ProjectCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def meta(self):
        """Gets the meta of this V1ProjectCreateRequest.  # noqa: E501


        :return: The meta of this V1ProjectCreateRequest.  # noqa: E501
        :rtype: V1Meta
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this V1ProjectCreateRequest.


        :param meta: The meta of this V1ProjectCreateRequest.  # noqa: E501
        :type: V1Meta
        """

        self._meta = meta

    @property
    def name(self):
        """Gets the name of this V1ProjectCreateRequest.  # noqa: E501


        :return: The name of this V1ProjectCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1ProjectCreateRequest.


        :param name: The name of this V1ProjectCreateRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def quotas(self):
        """Gets the quotas of this V1ProjectCreateRequest.  # noqa: E501


        :return: The quotas of this V1ProjectCreateRequest.  # noqa: E501
        :rtype: V1QuotaSet
        """
        return self._quotas

    @quotas.setter
    def quotas(self, quotas):
        """Sets the quotas of this V1ProjectCreateRequest.


        :param quotas: The quotas of this V1ProjectCreateRequest.  # noqa: E501
        :type: V1QuotaSet
        """

        self._quotas = quotas

    @property
    def tenant_id(self):
        """Gets the tenant_id of this V1ProjectCreateRequest.  # noqa: E501


        :return: The tenant_id of this V1ProjectCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this V1ProjectCreateRequest.


        :param tenant_id: The tenant_id of this V1ProjectCreateRequest.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ProjectCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ProjectCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.ip_api import IpApi  # noqa: E501
from metal_python.rest import ApiException


class TestIpApi(unittest.TestCase):
    """IpApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.ip_api.IpApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_allocate_ip(self):
        """Test case for allocate_ip

        allocate an ip in the given network.  # noqa: E501
        """
        pass

    def test_allocate_specific_ip(self):
        """Test case for allocate_specific_ip

        allocate a specific ip in the given network.  # noqa: E501
        """
        pass

    def test_find_i_ps(self):
        """Test case for find_i_ps

        get all ips that match given properties  # noqa: E501
        """
        pass

    def test_find_ip(self):
        """Test case for find_ip

        get ip by id  # noqa: E501
        """
        pass

    def test_free_ip(self):
        """Test case for free_ip

        frees an ip  # noqa: E501
        """
        pass

    def test_list_i_ps(self):
        """Test case for list_i_ps

        get all ips  # noqa: E501
        """
        pass

    def test_update_ip(self):
        """Test case for update_ip

        updates an ip. if the ip was changed since this one was read, a conflict is returned  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineNetwork(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asn': 'int',
        'destinationprefixes': 'list[str]',
        'ips': 'list[str]',
        'nat': 'bool',
        'networkid': 'str',
        'prefixes': 'list[str]',
        'private': 'bool',
        'underlay': 'bool',
        'vrf': 'int'
    }

    attribute_map = {
        'asn': 'asn',
        'destinationprefixes': 'destinationprefixes',
        'ips': 'ips',
        'nat': 'nat',
        'networkid': 'networkid',
        'prefixes': 'prefixes',
        'private': 'private',
        'underlay': 'underlay',
        'vrf': 'vrf'
    }

    def __init__(self, asn=None, destinationprefixes=None, ips=None, nat=None, networkid=None, prefixes=None, private=None, underlay=None, vrf=None):  # noqa: E501
        """V1MachineNetwork - a model defined in Swagger"""  # noqa: E501

        self._asn = None
        self._destinationprefixes = None
        self._ips = None
        self._nat = None
        self._networkid = None
        self._prefixes = None
        self._private = None
        self._underlay = None
        self._vrf = None
        self.discriminator = None

        self.asn = asn
        self.destinationprefixes = destinationprefixes
        self.ips = ips
        self.nat = nat
        self.networkid = networkid
        self.prefixes = prefixes
        self.private = private
        self.underlay = underlay
        self.vrf = vrf

    @property
    def asn(self):
        """Gets the asn of this V1MachineNetwork.  # noqa: E501

        ASN number for this network in the bgp configuration  # noqa: E501

        :return: The asn of this V1MachineNetwork.  # noqa: E501
        :rtype: int
        """
        return self._asn

    @asn.setter
    def asn(self, asn):
        """Sets the asn of this V1MachineNetwork.

        ASN number for this network in the bgp configuration  # noqa: E501

        :param asn: The asn of this V1MachineNetwork.  # noqa: E501
        :type: int
        """
        if asn is None:
            raise ValueError("Invalid value for `asn`, must not be `None`")  # noqa: E501

        self._asn = asn

    @property
    def destinationprefixes(self):
        """Gets the destinationprefixes of this V1MachineNetwork.  # noqa: E501

        the destination prefixes of this network  # noqa: E501

        :return: The destinationprefixes of this V1MachineNetwork.  # noqa: E501
        :rtype: list[str]
        """
        return self._destinationprefixes

    @destinationprefixes.setter
    def destinationprefixes(self, destinationprefixes):
        """Sets the destinationprefixes of this V1MachineNetwork.

        the destination prefixes of this network  # noqa: E501

        :param destinationprefixes: The destinationprefixes of this V1MachineNetwork.  # noqa: E501
        :type: list[str]
        """
        if destinationprefixes is None:
            raise ValueError("Invalid value for `destinationprefixes`, must not be `None`")  # noqa: E501

        self._destinationprefixes = destinationprefixes

    @property
    def ips(self):
        """Gets the ips of this V1MachineNetwork.  # noqa: E501

        the ip addresses of the allocated machine in this vrf  # noqa: E501

        :return: The ips of this V1MachineNetwork.  # noqa: E501
        :rtype: list[str]
        """
        return self._ips

    @ips.setter
    def ips(self, ips):
        """Sets the ips of this V1MachineNetwork.

        the ip addresses of the allocated machine in this vrf  # noqa: E501

        :param ips: The ips of this V1MachineNetwork.  # noqa: E501
        :type: list[str]
        """
        if ips is None:
            raise ValueError("Invalid value for `ips`, must not be `None`")  # noqa: E501

        self._ips = ips

    @property
    def nat(self):
        """Gets the nat of this V1MachineNetwork.  # noqa: E501

        if set to true, packets leaving this network get masqueraded behind interface ip  # noqa: E501

        :return: The nat of this V1MachineNetwork.  # noqa: E501
        :rtype: bool
        """
        return self._nat

    @nat.setter
    def nat(self, nat):
        """Sets the nat of this V1MachineNetwork.

        if set to true, packets leaving this network get masqueraded behind interface ip  # noqa: E501

        :param nat: The nat of this V1MachineNetwork.  # noqa: E501
        :type: bool
        """
        if nat is None:
            raise ValueError("Invalid value for `nat`, must not be `None`")  # noqa: E501

        self._nat = nat

    @property
    def networkid(self):
        """Gets the networkid of this V1MachineNetwork.  # noqa: E501

        the networkID of the allocated machine in this vrf  # noqa: E501

        :return: The networkid of this V1MachineNetwork.  # noqa: E501
        :rtype: str
        """
        return self._networkid

    @networkid.setter
    def networkid(self, networkid):
        """Sets the networkid of this V1MachineNetwork.

        the networkID of the allocated machine in this vrf  # noqa: E501

        :param networkid: The networkid of this V1MachineNetwork.  # noqa: E501
        :type: str
        """
        if networkid is None:
            raise ValueError("Invalid value for `networkid`, must not be `None`")  # noqa: E501

        self._networkid = networkid

    @property
    def prefixes(self):
        """Gets the prefixes of this V1MachineNetwork.  # noqa: E501

        the prefixes of this network  # noqa: E501

        :return: The prefixes of this V1MachineNetwork.  # noqa: E501
        :rtype: list[str]
        """
        return self._prefixes

    @prefixes.setter
    def prefixes(self, prefixes):
        """Sets the prefixes of this V1MachineNetwork.

        the prefixes of this network  # noqa: E501

        :param prefixes: The prefixes of this V1MachineNetwork.  # noqa: E501
        :type: list[str]
        """
        if prefixes is None:
            raise ValueError("Invalid value for `prefixes`, must not be `None`")  # noqa: E501

        self._prefixes = prefixes

    @property
    def private(self):
        """Gets the private of this V1MachineNetwork.  # noqa: E501

        indicates whether this network is the private network of this machine  # noqa: E501

        :return: The private of this V1MachineNetwork.  # noqa: E501
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private):
        """Sets the private of this V1MachineNetwork.

        indicates whether this network is the private network of this machine  # noqa: E501

        :param private: The private of this V1MachineNetwork.  # noqa: E501
        :type: bool
        """
        if private is None:
            raise ValueError("Invalid value for `private`, must not be `None`")  # noqa: E501

        self._private = private

    @property
    def underlay(self):
        """Gets the underlay of this V1MachineNetwork.  # noqa: E501

        if set to true, this network can be used for underlay communication  # noqa: E501

        :return: The underlay of this V1MachineNetwork.  # noqa: E501
        :rtype: bool
        """
        return self._underlay

    @underlay.setter
    def underlay(self, underlay):
        """Sets the underlay of this V1MachineNetwork.

        if set to true, this network can be used for underlay communication  # noqa: E501

        :param underlay: The underlay of this V1MachineNetwork.  # noqa: E501
        :type: bool
        """
        if underlay is None:
            raise ValueError("Invalid value for `underlay`, must not be `None`")  # noqa: E501

        self._underlay = underlay

    @property
    def vrf(self):
        """Gets the vrf of this V1MachineNetwork.  # noqa: E501

        the vrf of the allocated machine  # noqa: E501

        :return: The vrf of this V1MachineNetwork.  # noqa: E501
        :rtype: int
        """
        return self._vrf

    @vrf.setter
    def vrf(self, vrf):
        """Sets the vrf of this V1MachineNetwork.

        the vrf of the allocated machine  # noqa: E501

        :param vrf: The vrf of this V1MachineNetwork.  # noqa: E501
        :type: int
        """
        if vrf is None:
            raise ValueError("Invalid value for `vrf`, must not be `None`")  # noqa: E501

        self._vrf = vrf

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineNetwork, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineNetwork):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from metal_python.api.partition_api import PartitionApi
from metal_python.api.firewall_api import FirewallApi
from metal_python.api.health_api import HealthApi
from metal_python.api.image_api import ImageApi
from metal_python.api.ip_api import IpApi
from metal_python.api.machine_api import MachineApi
from metal_python.api.network_api import NetworkApi
from metal_python.api.project_api import ProjectApi
from metal_python.api.size_api import SizeApi
from metal_python.api.switch_api import SwitchApi
from metal_python.api.version_api import VersionApi



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1Meta(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'annotations': 'dict(str, str)',
        'apiversion': 'str',
        'created_time': 'datetime',
        'id': 'str',
        'kind': 'str',
        'labels': 'list[str]',
        'updated_time': 'datetime',
        'version': 'int'
    }

    attribute_map = {
        'annotations': 'annotations',
        'apiversion': 'apiversion',
        'created_time': 'created_time',
        'id': 'id',
        'kind': 'kind',
        'labels': 'labels',
        'updated_time': 'updated_time',
        'version': 'version'
    }

    def __init__(self, annotations=None, apiversion=None, created_time=None, id=None, kind=None, labels=None, updated_time=None, version=None):  # noqa: E501
        """V1Meta - a model defined in Swagger"""  # noqa: E501

        self._annotations = None
        self._apiversion = None
        self._created_time = None
        self._id = None
        self._kind = None
        self._labels = None
        self._updated_time = None
        self._version = None
        self.discriminator = None

        if annotations is not None:
            self.annotations = annotations
        if apiversion is not None:
            self.apiversion = apiversion
        if created_time is not None:
            self.created_time = created_time
        if id is not None:
            self.id = id
        if kind is not None:
            self.kind = kind
        if labels is not None:
            self.labels = labels
        if updated_time is not None:
            self.updated_time = updated_time
        if version is not None:
            self.version = version

    @property
    def annotations(self):
        """Gets the annotations of this V1Meta.  # noqa: E501


        :return: The annotations of this V1Meta.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this V1Meta.


        :param annotations: The annotations of this V1Meta.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def apiversion(self):
        """Gets the apiversion of this V1Meta.  # noqa: E501


        :return: The apiversion of this V1Meta.  # noqa: E501
        :rtype: str
        """
        return self._apiversion

    @apiversion.setter
    def apiversion(self, apiversion):
        """Sets the apiversion of this V1Meta.


        :param apiversion: The apiversion of this V1Meta.  # noqa: E501
        :type: str
        """

        self._apiversion = apiversion

    @property
    def created_time(self):
        """Gets the created_time of this V1Meta.  # noqa: E501


        :return: The created_time of this V1Meta.  # noqa: E501
        :rtype: datetime
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this V1Meta.


        :param created_time: The created_time of this V1Meta.  # noqa: E501
        :type: datetime
        """

        self._created_time = created_time

    @property
    def id(self):
        """Gets the id of this V1Meta.  # noqa: E501


        :return: The id of this V1Meta.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this V1Meta.


        :param id: The id of this V1Meta.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def kind(self):
        """Gets the kind of this V1Meta.  # noqa: E501


        :return: The kind of this V1Meta.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this V1Meta.


        :param kind: The kind of this V1Meta.  # noqa: E501
        :type: str
        """

        self._kind = kind

    @property
    def labels(self):
        """Gets the labels of this V1Meta.  # noqa: E501


        :return: The labels of this V1Meta.  # noqa: E501
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this V1Meta.


        :param labels: The labels of this V1Meta.  # noqa: E501
        :type: list[str]
        """

        self._labels = labels

    @property
    def updated_time(self):
        """Gets the updated_time of this V1Meta.  # noqa: E501


        :return: The updated_time of this V1Meta.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_time

    @updated_time.setter
    def updated_time(self, updated_time):
        """Sets the updated_time of this V1Meta.


        :param updated_time: The updated_time of this V1Meta.  # noqa: E501
        :type: datetime
        """

        self._updated_time = updated_time

    @property
    def version(self):
        """Gets the version of this V1Meta.  # noqa: E501


        :return: The version of this V1Meta.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this V1Meta.


        :param version: The version of this V1Meta.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Meta, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Meta):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1ImageResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'changed': 'datetime',
        'classification': 'str',
        'created': 'datetime',
        'description': 'str',
        'expiration_date': 'datetime',
        'features': 'list[str]',
        'id': 'str',
        'name': 'str',
        'url': 'str',
        'usedby': 'list[str]'
    }

    attribute_map = {
        'changed': 'changed',
        'classification': 'classification',
        'created': 'created',
        'description': 'description',
        'expiration_date': 'expirationDate',
        'features': 'features',
        'id': 'id',
        'name': 'name',
        'url': 'url',
        'usedby': 'usedby'
    }

    def __init__(self, changed=None, classification=None, created=None, description=None, expiration_date=None, features=None, id=None, name=None, url=None, usedby=None):  # noqa: E501
        """V1ImageResponse - a model defined in Swagger"""  # noqa: E501

        self._changed = None
        self._classification = None
        self._created = None
        self._description = None
        self._expiration_date = None
        self._features = None
        self._id = None
        self._name = None
        self._url = None
        self._usedby = None
        self.discriminator = None

        if changed is not None:
            self.changed = changed
        if classification is not None:
            self.classification = classification
        if created is not None:
            self.created = created
        if description is not None:
            self.description = description
        self.expiration_date = expiration_date
        if features is not None:
            self.features = features
        self.id = id
        if name is not None:
            self.name = name
        if url is not None:
            self.url = url
        if usedby is not None:
            self.usedby = usedby

    @property
    def changed(self):
        """Gets the changed of this V1ImageResponse.  # noqa: E501

        the last changed timestamp of this entity  # noqa: E501

        :return: The changed of this V1ImageResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._changed

    @changed.setter
    def changed(self, changed):
        """Sets the changed of this V1ImageResponse.

        the last changed timestamp of this entity  # noqa: E501

        :param changed: The changed of this V1ImageResponse.  # noqa: E501
        :type: datetime
        """

        self._changed = changed

    @property
    def classification(self):
        """Gets the classification of this V1ImageResponse.  # noqa: E501

        classification of this image  # noqa: E501

        :return: The classification of this V1ImageResponse.  # noqa: E501
        :rtype: str
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        """Sets the classification of this V1ImageResponse.

        classification of this image  # noqa: E501

        :param classification: The classification of this V1ImageResponse.  # noqa: E501
        :type: str
        """

        self._classification = classification

    @property
    def created(self):
        """Gets the created of this V1ImageResponse.  # noqa: E501

        the creation time of this entity  # noqa: E501

        :return: The created of this V1ImageResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this V1ImageResponse.

        the creation time of this entity  # noqa: E501

        :param created: The created of this V1ImageResponse.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def description(self):
        """Gets the description of this V1ImageResponse.  # noqa: E501

        a description for this entity  # noqa: E501

        :return: The description of this V1ImageResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1ImageResponse.

        a description for this entity  # noqa: E501

        :param description: The description of this V1ImageResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def expiration_date(self):
        """Gets the expiration_date of this V1ImageResponse.  # noqa: E501

        expirationDate of this image  # noqa: E501

        :return: The expiration_date of this V1ImageResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this V1ImageResponse.

        expirationDate of this image  # noqa: E501

        :param expiration_date: The expiration_date of this V1ImageResponse.  # noqa: E501
        :type: datetime
        """
        if expiration_date is None:
            raise ValueError("Invalid value for `expiration_date`, must not be `None`")  # noqa: E501

        self._expiration_date = expiration_date

    @property
    def features(self):
        """Gets the features of this V1ImageResponse.  # noqa: E501

        features of this image  # noqa: E501

        :return: The features of this V1ImageResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this V1ImageResponse.

        features of this image  # noqa: E501

        :param features: The features of this V1ImageResponse.  # noqa: E501
        :type: list[str]
        """

        self._features = features

    @property
    def id(self):
        """Gets the id of this V1ImageResponse.  # noqa: E501

        the unique ID of this entity  # noqa: E501

        :return: The id of this V1ImageResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this V1ImageResponse.

        the unique ID of this entity  # noqa: E501

        :param id: The id of this V1ImageResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this V1ImageResponse.  # noqa: E501

        a readable name for this entity  # noqa: E501

        :return: The name of this V1ImageResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1ImageResponse.

        a readable name for this entity  # noqa: E501

        :param name: The name of this V1ImageResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def url(self):
        """Gets the url of this V1ImageResponse.  # noqa: E501

        the url of this image  # noqa: E501

        :return: The url of this V1ImageResponse.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this V1ImageResponse.

        the url of this image  # noqa: E501

        :param url: The url of this V1ImageResponse.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def usedby(self):
        """Gets the usedby of this V1ImageResponse.  # noqa: E501

        machines where this image is in use  # noqa: E501

        :return: The usedby of this V1ImageResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._usedby

    @usedby.setter
    def usedby(self, usedby):
        """Sets the usedby of this V1ImageResponse.

        machines where this image is in use  # noqa: E501

        :param usedby: The usedby of this V1ImageResponse.  # noqa: E501
        :type: list[str]
        """

        self._usedby = usedby

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ImageResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ImageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineFinalizeAllocationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bootloaderid': 'str',
        'cmdline': 'str',
        'console_password': 'str',
        'initrd': 'str',
        'kernel': 'str',
        'ospartition': 'str',
        'primarydisk': 'str'
    }

    attribute_map = {
        'bootloaderid': 'bootloaderid',
        'cmdline': 'cmdline',
        'console_password': 'console_password',
        'initrd': 'initrd',
        'kernel': 'kernel',
        'ospartition': 'ospartition',
        'primarydisk': 'primarydisk'
    }

    def __init__(self, bootloaderid=None, cmdline=None, console_password=None, initrd=None, kernel=None, ospartition=None, primarydisk=None):  # noqa: E501
        """V1MachineFinalizeAllocationRequest - a model defined in Swagger"""  # noqa: E501

        self._bootloaderid = None
        self._cmdline = None
        self._console_password = None
        self._initrd = None
        self._kernel = None
        self._ospartition = None
        self._primarydisk = None
        self.discriminator = None

        self.bootloaderid = bootloaderid
        self.cmdline = cmdline
        self.console_password = console_password
        self.initrd = initrd
        self.kernel = kernel
        self.ospartition = ospartition
        self.primarydisk = primarydisk

    @property
    def bootloaderid(self):
        """Gets the bootloaderid of this V1MachineFinalizeAllocationRequest.  # noqa: E501

        the bootloader ID  # noqa: E501

        :return: The bootloaderid of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._bootloaderid

    @bootloaderid.setter
    def bootloaderid(self, bootloaderid):
        """Sets the bootloaderid of this V1MachineFinalizeAllocationRequest.

        the bootloader ID  # noqa: E501

        :param bootloaderid: The bootloaderid of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :type: str
        """
        if bootloaderid is None:
            raise ValueError("Invalid value for `bootloaderid`, must not be `None`")  # noqa: E501

        self._bootloaderid = bootloaderid

    @property
    def cmdline(self):
        """Gets the cmdline of this V1MachineFinalizeAllocationRequest.  # noqa: E501

        the cmdline  # noqa: E501

        :return: The cmdline of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._cmdline

    @cmdline.setter
    def cmdline(self, cmdline):
        """Sets the cmdline of this V1MachineFinalizeAllocationRequest.

        the cmdline  # noqa: E501

        :param cmdline: The cmdline of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :type: str
        """
        if cmdline is None:
            raise ValueError("Invalid value for `cmdline`, must not be `None`")  # noqa: E501

        self._cmdline = cmdline

    @property
    def console_password(self):
        """Gets the console_password of this V1MachineFinalizeAllocationRequest.  # noqa: E501

        the console password which was generated while provisioning  # noqa: E501

        :return: The console_password of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._console_password

    @console_password.setter
    def console_password(self, console_password):
        """Sets the console_password of this V1MachineFinalizeAllocationRequest.

        the console password which was generated while provisioning  # noqa: E501

        :param console_password: The console_password of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :type: str
        """
        if console_password is None:
            raise ValueError("Invalid value for `console_password`, must not be `None`")  # noqa: E501

        self._console_password = console_password

    @property
    def initrd(self):
        """Gets the initrd of this V1MachineFinalizeAllocationRequest.  # noqa: E501

        the initrd image  # noqa: E501

        :return: The initrd of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._initrd

    @initrd.setter
    def initrd(self, initrd):
        """Sets the initrd of this V1MachineFinalizeAllocationRequest.

        the initrd image  # noqa: E501

        :param initrd: The initrd of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :type: str
        """
        if initrd is None:
            raise ValueError("Invalid value for `initrd`, must not be `None`")  # noqa: E501

        self._initrd = initrd

    @property
    def kernel(self):
        """Gets the kernel of this V1MachineFinalizeAllocationRequest.  # noqa: E501

        the kernel  # noqa: E501

        :return: The kernel of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._kernel

    @kernel.setter
    def kernel(self, kernel):
        """Sets the kernel of this V1MachineFinalizeAllocationRequest.

        the kernel  # noqa: E501

        :param kernel: The kernel of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :type: str
        """
        if kernel is None:
            raise ValueError("Invalid value for `kernel`, must not be `None`")  # noqa: E501

        self._kernel = kernel

    @property
    def ospartition(self):
        """Gets the ospartition of this V1MachineFinalizeAllocationRequest.  # noqa: E501

        the partition that has the OS installed  # noqa: E501

        :return: The ospartition of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._ospartition

    @ospartition.setter
    def ospartition(self, ospartition):
        """Sets the ospartition of this V1MachineFinalizeAllocationRequest.

        the partition that has the OS installed  # noqa: E501

        :param ospartition: The ospartition of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :type: str
        """
        if ospartition is None:
            raise ValueError("Invalid value for `ospartition`, must not be `None`")  # noqa: E501

        self._ospartition = ospartition

    @property
    def primarydisk(self):
        """Gets the primarydisk of this V1MachineFinalizeAllocationRequest.  # noqa: E501

        the device name of the primary disk  # noqa: E501

        :return: The primarydisk of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :rtype: str
        """
        return self._primarydisk

    @primarydisk.setter
    def primarydisk(self, primarydisk):
        """Sets the primarydisk of this V1MachineFinalizeAllocationRequest.

        the device name of the primary disk  # noqa: E501

        :param primarydisk: The primarydisk of this V1MachineFinalizeAllocationRequest.  # noqa: E501
        :type: str
        """
        if primarydisk is None:
            raise ValueError("Invalid value for `primarydisk`, must not be `None`")  # noqa: E501

        self._primarydisk = primarydisk

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineFinalizeAllocationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineFinalizeAllocationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1NetworkAllocateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'labels': 'dict(str, str)',
        'name': 'str',
        'partitionid': 'str',
        'projectid': 'str'
    }

    attribute_map = {
        'description': 'description',
        'labels': 'labels',
        'name': 'name',
        'partitionid': 'partitionid',
        'projectid': 'projectid'
    }

    def __init__(self, description=None, labels=None, name=None, partitionid=None, projectid=None):  # noqa: E501
        """V1NetworkAllocateRequest - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._labels = None
        self._name = None
        self._partitionid = None
        self._projectid = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if labels is not None:
            self.labels = labels
        if name is not None:
            self.name = name
        if partitionid is not None:
            self.partitionid = partitionid
        if projectid is not None:
            self.projectid = projectid

    @property
    def description(self):
        """Gets the description of this V1NetworkAllocateRequest.  # noqa: E501

        a description for this entity  # noqa: E501

        :return: The description of this V1NetworkAllocateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1NetworkAllocateRequest.

        a description for this entity  # noqa: E501

        :param description: The description of this V1NetworkAllocateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def labels(self):
        """Gets the labels of this V1NetworkAllocateRequest.  # noqa: E501

        free labels that you associate with this network.  # noqa: E501

        :return: The labels of this V1NetworkAllocateRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this V1NetworkAllocateRequest.

        free labels that you associate with this network.  # noqa: E501

        :param labels: The labels of this V1NetworkAllocateRequest.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def name(self):
        """Gets the name of this V1NetworkAllocateRequest.  # noqa: E501

        a readable name for this entity  # noqa: E501

        :return: The name of this V1NetworkAllocateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1NetworkAllocateRequest.

        a readable name for this entity  # noqa: E501

        :param name: The name of this V1NetworkAllocateRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def partitionid(self):
        """Gets the partitionid of this V1NetworkAllocateRequest.  # noqa: E501

        the partition this network belongs to  # noqa: E501

        :return: The partitionid of this V1NetworkAllocateRequest.  # noqa: E501
        :rtype: str
        """
        return self._partitionid

    @partitionid.setter
    def partitionid(self, partitionid):
        """Sets the partitionid of this V1NetworkAllocateRequest.

        the partition this network belongs to  # noqa: E501

        :param partitionid: The partitionid of this V1NetworkAllocateRequest.  # noqa: E501
        :type: str
        """

        self._partitionid = partitionid

    @property
    def projectid(self):
        """Gets the projectid of this V1NetworkAllocateRequest.  # noqa: E501

        the project id this network belongs to, can be empty if globally available  # noqa: E501

        :return: The projectid of this V1NetworkAllocateRequest.  # noqa: E501
        :rtype: str
        """
        return self._projectid

    @projectid.setter
    def projectid(self, projectid):
        """Sets the projectid of this V1NetworkAllocateRequest.

        the project id this network belongs to, can be empty if globally available  # noqa: E501

        :param projectid: The projectid of this V1NetworkAllocateRequest.  # noqa: E501
        :type: str
        """

        self._projectid = projectid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1NetworkAllocateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1NetworkAllocateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineRecentProvisioningEvents(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'incomplete_provisioning_cycles': 'str',
        'last_event_time': 'datetime',
        'log': 'list[V1MachineProvisioningEvent]'
    }

    attribute_map = {
        'incomplete_provisioning_cycles': 'incomplete_provisioning_cycles',
        'last_event_time': 'last_event_time',
        'log': 'log'
    }

    def __init__(self, incomplete_provisioning_cycles=None, last_event_time=None, log=None):  # noqa: E501
        """V1MachineRecentProvisioningEvents - a model defined in Swagger"""  # noqa: E501

        self._incomplete_provisioning_cycles = None
        self._last_event_time = None
        self._log = None
        self.discriminator = None

        self.incomplete_provisioning_cycles = incomplete_provisioning_cycles
        self.last_event_time = last_event_time
        self.log = log

    @property
    def incomplete_provisioning_cycles(self):
        """Gets the incomplete_provisioning_cycles of this V1MachineRecentProvisioningEvents.  # noqa: E501

        the amount of incomplete provisioning cycles in the event container  # noqa: E501

        :return: The incomplete_provisioning_cycles of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :rtype: str
        """
        return self._incomplete_provisioning_cycles

    @incomplete_provisioning_cycles.setter
    def incomplete_provisioning_cycles(self, incomplete_provisioning_cycles):
        """Sets the incomplete_provisioning_cycles of this V1MachineRecentProvisioningEvents.

        the amount of incomplete provisioning cycles in the event container  # noqa: E501

        :param incomplete_provisioning_cycles: The incomplete_provisioning_cycles of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :type: str
        """
        if incomplete_provisioning_cycles is None:
            raise ValueError("Invalid value for `incomplete_provisioning_cycles`, must not be `None`")  # noqa: E501

        self._incomplete_provisioning_cycles = incomplete_provisioning_cycles

    @property
    def last_event_time(self):
        """Gets the last_event_time of this V1MachineRecentProvisioningEvents.  # noqa: E501

        the time where the last event was received  # noqa: E501

        :return: The last_event_time of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :rtype: datetime
        """
        return self._last_event_time

    @last_event_time.setter
    def last_event_time(self, last_event_time):
        """Sets the last_event_time of this V1MachineRecentProvisioningEvents.

        the time where the last event was received  # noqa: E501

        :param last_event_time: The last_event_time of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :type: datetime
        """
        if last_event_time is None:
            raise ValueError("Invalid value for `last_event_time`, must not be `None`")  # noqa: E501

        self._last_event_time = last_event_time

    @property
    def log(self):
        """Gets the log of this V1MachineRecentProvisioningEvents.  # noqa: E501

        the log of recent machine provisioning events  # noqa: E501

        :return: The log of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :rtype: list[V1MachineProvisioningEvent]
        """
        return self._log

    @log.setter
    def log(self, log):
        """Sets the log of this V1MachineRecentProvisioningEvents.

        the log of recent machine provisioning events  # noqa: E501

        :param log: The log of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :type: list[V1MachineProvisioningEvent]
        """
        if log is None:
            raise ValueError("Invalid value for `log`, must not be `None`")  # noqa: E501

        self._log = log

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineRecentProvisioningEvents, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineRecentProvisioningEvents):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineDiskPartition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'device': 'str',
        'filesystem': 'str',
        'gptguid': 'str',
        'gpttyoe': 'str',
        'label': 'str',
        'mountoptions': 'list[str]',
        'mountpoint': 'str',
        'number': 'int',
        'properties': 'dict(str, str)',
        'size': 'int'
    }

    attribute_map = {
        'device': 'device',
        'filesystem': 'filesystem',
        'gptguid': 'gptguid',
        'gpttyoe': 'gpttyoe',
        'label': 'label',
        'mountoptions': 'mountoptions',
        'mountpoint': 'mountpoint',
        'number': 'number',
        'properties': 'properties',
        'size': 'size'
    }

    def __init__(self, device=None, filesystem=None, gptguid=None, gpttyoe=None, label=None, mountoptions=None, mountpoint=None, number=None, properties=None, size=None):  # noqa: E501
        """V1MachineDiskPartition - a model defined in Swagger"""  # noqa: E501

        self._device = None
        self._filesystem = None
        self._gptguid = None
        self._gpttyoe = None
        self._label = None
        self._mountoptions = None
        self._mountpoint = None
        self._number = None
        self._properties = None
        self._size = None
        self.discriminator = None

        self.device = device
        self.filesystem = filesystem
        self.gptguid = gptguid
        self.gpttyoe = gpttyoe
        self.label = label
        self.mountoptions = mountoptions
        self.mountpoint = mountpoint
        self.number = number
        self.properties = properties
        self.size = size

    @property
    def device(self):
        """Gets the device of this V1MachineDiskPartition.  # noqa: E501

        the partition device name, e.g. sda1  # noqa: E501

        :return: The device of this V1MachineDiskPartition.  # noqa: E501
        :rtype: str
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this V1MachineDiskPartition.

        the partition device name, e.g. sda1  # noqa: E501

        :param device: The device of this V1MachineDiskPartition.  # noqa: E501
        :type: str
        """
        if device is None:
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    @property
    def filesystem(self):
        """Gets the filesystem of this V1MachineDiskPartition.  # noqa: E501

        the partition filesystem  # noqa: E501

        :return: The filesystem of this V1MachineDiskPartition.  # noqa: E501
        :rtype: str
        """
        return self._filesystem

    @filesystem.setter
    def filesystem(self, filesystem):
        """Sets the filesystem of this V1MachineDiskPartition.

        the partition filesystem  # noqa: E501

        :param filesystem: The filesystem of this V1MachineDiskPartition.  # noqa: E501
        :type: str
        """
        if filesystem is None:
            raise ValueError("Invalid value for `filesystem`, must not be `None`")  # noqa: E501

        self._filesystem = filesystem

    @property
    def gptguid(self):
        """Gets the gptguid of this V1MachineDiskPartition.  # noqa: E501

        the partition GPT guid  # noqa: E501

        :return: The gptguid of this V1MachineDiskPartition.  # noqa: E501
        :rtype: str
        """
        return self._gptguid

    @gptguid.setter
    def gptguid(self, gptguid):
        """Sets the gptguid of this V1MachineDiskPartition.

        the partition GPT guid  # noqa: E501

        :param gptguid: The gptguid of this V1MachineDiskPartition.  # noqa: E501
        :type: str
        """
        if gptguid is None:
            raise ValueError("Invalid value for `gptguid`, must not be `None`")  # noqa: E501

        self._gptguid = gptguid

    @property
    def gpttyoe(self):
        """Gets the gpttyoe of this V1MachineDiskPartition.  # noqa: E501

        the partition GPT type  # noqa: E501

        :return: The gpttyoe of this V1MachineDiskPartition.  # noqa: E501
        :rtype: str
        """
        return self._gpttyoe

    @gpttyoe.setter
    def gpttyoe(self, gpttyoe):
        """Sets the gpttyoe of this V1MachineDiskPartition.

        the partition GPT type  # noqa: E501

        :param gpttyoe: The gpttyoe of this V1MachineDiskPartition.  # noqa: E501
        :type: str
        """
        if gpttyoe is None:
            raise ValueError("Invalid value for `gpttyoe`, must not be `None`")  # noqa: E501

        self._gpttyoe = gpttyoe

    @property
    def label(self):
        """Gets the label of this V1MachineDiskPartition.  # noqa: E501

        the partition label  # noqa: E501

        :return: The label of this V1MachineDiskPartition.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this V1MachineDiskPartition.

        the partition label  # noqa: E501

        :param label: The label of this V1MachineDiskPartition.  # noqa: E501
        :type: str
        """
        if label is None:
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def mountoptions(self):
        """Gets the mountoptions of this V1MachineDiskPartition.  # noqa: E501

        the partition mount options  # noqa: E501

        :return: The mountoptions of this V1MachineDiskPartition.  # noqa: E501
        :rtype: list[str]
        """
        return self._mountoptions

    @mountoptions.setter
    def mountoptions(self, mountoptions):
        """Sets the mountoptions of this V1MachineDiskPartition.

        the partition mount options  # noqa: E501

        :param mountoptions: The mountoptions of this V1MachineDiskPartition.  # noqa: E501
        :type: list[str]
        """
        if mountoptions is None:
            raise ValueError("Invalid value for `mountoptions`, must not be `None`")  # noqa: E501

        self._mountoptions = mountoptions

    @property
    def mountpoint(self):
        """Gets the mountpoint of this V1MachineDiskPartition.  # noqa: E501

        the partition mount point  # noqa: E501

        :return: The mountpoint of this V1MachineDiskPartition.  # noqa: E501
        :rtype: str
        """
        return self._mountpoint

    @mountpoint.setter
    def mountpoint(self, mountpoint):
        """Sets the mountpoint of this V1MachineDiskPartition.

        the partition mount point  # noqa: E501

        :param mountpoint: The mountpoint of this V1MachineDiskPartition.  # noqa: E501
        :type: str
        """
        if mountpoint is None:
            raise ValueError("Invalid value for `mountpoint`, must not be `None`")  # noqa: E501

        self._mountpoint = mountpoint

    @property
    def number(self):
        """Gets the number of this V1MachineDiskPartition.  # noqa: E501

        the partition number  # noqa: E501

        :return: The number of this V1MachineDiskPartition.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this V1MachineDiskPartition.

        the partition number  # noqa: E501

        :param number: The number of this V1MachineDiskPartition.  # noqa: E501
        :type: int
        """
        if number is None:
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def properties(self):
        """Gets the properties of this V1MachineDiskPartition.  # noqa: E501

        the partition properties  # noqa: E501

        :return: The properties of this V1MachineDiskPartition.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this V1MachineDiskPartition.

        the partition properties  # noqa: E501

        :param properties: The properties of this V1MachineDiskPartition.  # noqa: E501
        :type: dict(str, str)
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    @property
    def size(self):
        """Gets the size of this V1MachineDiskPartition.  # noqa: E501

        the partition size  # noqa: E501

        :return: The size of this V1MachineDiskPartition.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this V1MachineDiskPartition.

        the partition size  # noqa: E501

        :param size: The size of this V1MachineDiskPartition.  # noqa: E501
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineDiskPartition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineDiskPartition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.image_api import ImageApi  # noqa: E501
from metal_python.rest import ApiException


class TestImageApi(unittest.TestCase):
    """ImageApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.image_api.ImageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_image(self):
        """Test case for create_image

        create an image. if the given ID already exists a conflict is returned  # noqa: E501
        """
        pass

    def test_delete_image(self):
        """Test case for delete_image

        deletes an image and returns the deleted entity  # noqa: E501
        """
        pass

    def test_find_image(self):
        """Test case for find_image

        get image by id  # noqa: E501
        """
        pass

    def test_find_latest_image(self):
        """Test case for find_latest_image

        find latest image by id  # noqa: E501
        """
        pass

    def test_list_images(self):
        """Test case for list_images

        get all images  # noqa: E501
        """
        pass

    def test_update_image(self):
        """Test case for update_image

        updates an image. if the image was changed since this one was read, a conflict is returned  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages
from version import VERSION

NAME = "metal_python"

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23",
    "wrapt",
]

setup(
    name=NAME,
    version=VERSION,
    description="Python API client for metal-api",
    author="metal-stack authors",
    url="https://github.com/metal-stack/metal-python",
    keywords=["metal-stack", "metal-api", "swagger", "swagger-client"],
    install_requires=REQUIRES,
    extras_require=dict(
        dev=[
            "nose",
            "coverage",
        ]
    ),
    license="MIT",
    packages=find_packages(),
    classifiers=[
        "License :: OSI Approved :: MIT License",
        'Intended Audience :: Developers',
        "License :: OSI Approved :: MIT License",
        'Natural Language :: English',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    include_package_data=True,
)
